# Select device to change

## Filter

### Show counts

By name

- All
- Smartphone John

MockedCsrfTokenNode
Action:
0 of 1 selected

| Short id | Name | Location count | Last Location | Picture count | Last Picture | Create date | Last update
--- | --- | --- | --- | --- | --- | --- | --- | ---
| xyz012 | Smartphone John | 1 | Jan. 1, 2000, 1:02 a.m. | 0 | - | Jan. 1, 2000, 1:01 a.m. | Jan. 1, 2000, 1:03 a.m.